{
    "$graph": [
        {
            "class": "Workflow",
            "inputs": [
                {
                    "type": "File",
                    "id": "#main/annotation"
                },
                {
                    "type": "Directory",
                    "id": "#main/genomeDir"
                },
                {
                    "type": "boolean",
                    "default": false,
                    "id": "#main/gzip"
                },
                {
                    "type": "int",
                    "id": "#main/nthreads"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#main/repo"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#main/run_ids"
                }
            ],
            "steps": [
                {
                    "run": "#cufflinks.cwl",
                    "in": [
                        {
                            "source": "#main/annotation",
                            "id": "#main/cufflinks/annotation"
                        },
                        {
                            "source": "#main/samtools_sort/sorted_bamfile",
                            "id": "#main/cufflinks/input_bam"
                        },
                        {
                            "source": "#main/nthreads",
                            "id": "#main/cufflinks/nthreads"
                        }
                    ],
                    "out": [
                        "#main/cufflinks/cufflinks_result"
                    ],
                    "id": "#main/cufflinks"
                },
                {
                    "run": "#download-sra.cwl",
                    "in": [
                        {
                            "source": "#main/repo",
                            "id": "#main/download-sra/repo"
                        },
                        {
                            "source": "#main/run_ids",
                            "id": "#main/download-sra/run_ids"
                        }
                    ],
                    "out": [
                        "#main/download-sra/sraFiles"
                    ],
                    "id": "#main/download-sra"
                },
                {
                    "run": "#pfastq-dump.cwl",
                    "in": [
                        {
                            "source": "#main/gzip",
                            "id": "#main/pfastq-dump/gzip"
                        },
                        {
                            "source": "#main/nthreads",
                            "id": "#main/pfastq-dump/nthreads"
                        },
                        {
                            "source": "#main/download-sra/sraFiles",
                            "id": "#main/pfastq-dump/sraFiles"
                        }
                    ],
                    "out": [
                        "#main/pfastq-dump/forward",
                        "#main/pfastq-dump/reverse"
                    ],
                    "id": "#main/pfastq-dump"
                },
                {
                    "run": "#samtools_sort.cwl",
                    "in": [
                        {
                            "source": "#main/star_mapping/output_bam",
                            "id": "#main/samtools_sort/input_bam"
                        },
                        {
                            "source": "#main/nthreads",
                            "id": "#main/samtools_sort/nthreads"
                        }
                    ],
                    "out": [
                        "#main/samtools_sort/sorted_bamfile"
                    ],
                    "id": "#main/samtools_sort"
                },
                {
                    "run": "#star_mapping_pe.cwl",
                    "in": [
                        {
                            "source": "#main/pfastq-dump/forward",
                            "id": "#main/star_mapping/fq1"
                        },
                        {
                            "source": "#main/pfastq-dump/reverse",
                            "id": "#main/star_mapping/fq2"
                        },
                        {
                            "source": "#main/genomeDir",
                            "id": "#main/star_mapping/genomeDir"
                        },
                        {
                            "source": "#main/nthreads",
                            "id": "#main/star_mapping/nthreads"
                        }
                    ],
                    "out": [
                        "#main/star_mapping/output_bam"
                    ],
                    "id": "#main/star_mapping"
                }
            ],
            "id": "#main",
            "https://schema.org/license": "https://spdx.org/licenses/Apache-2.0",
            "https://schema.org/codeRepository": "https://github.com/pitagora-network/pitagora-cwl",
            "https://schema.org/author": [
                {
                    "class": "https://schema.org/Person",
                    "https://schema.org/identifier": "https://orcid.org/0000-0003-3777-5945",
                    "https://schema.org/email": "mailto:inutano@gmail.com",
                    "https://schema.org/name": "Tazro Ohta"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/cufflinks/cufflinks_result",
                    "id": "#main/cufflinks_result"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "Cufflinks: Transcriptome assembly and differential expression analysis for RNA-Seq",
            "doc": "Transcriptome assembly and differential expression analysis for RNA-Seq. http://cole-trapnell-lab.github.io/cufflinks/cufflinks/index.html",
            "hints": [
                {
                    "dockerPull": "quay.io/biocontainers/cufflinks:2.2.1--py27_2",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": "cufflinks",
            "arguments": [
                {
                    "prefix": "-o",
                    "valueFrom": "$(runtime.outdir)"
                }
            ],
            "inputs": [
                {
                    "label": "quantitate against reference transcript annotations",
                    "doc": "quantitate against reference transcript annotations",
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--GTF"
                    },
                    "id": "#cufflinks.cwl/annotation"
                },
                {
                    "label": "Input bam file for cufflinks",
                    "doc": "Input bam file for cufflinks",
                    "type": "File",
                    "inputBinding": {
                        "position": 50
                    },
                    "id": "#cufflinks.cwl/input_bam"
                },
                {
                    "label": "number of threads used during analysis",
                    "doc": "number of threads used during analysis",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "-p"
                    },
                    "id": "#cufflinks.cwl/nthreads"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*"
                    },
                    "id": "#cufflinks.cwl/cufflinks_result"
                }
            ],
            "id": "#cufflinks.cwl",
            "https://schema.org/license": "https://spdx.org/licenses/Apache-2.0",
            "https://schema.org/codeRepository": "https://github.com/pitagora-network/pitagora-cwl",
            "https://schema.org/author": [
                {
                    "class": "https://schema.org/Person",
                    "https://schema.org/identifier": "https://orcid.org/0000-0003-3777-5945",
                    "https://schema.org/email": "mailto:inutano@gmail.com",
                    "https://schema.org/name": "Tazro Ohta"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "download-sra: A simple download tool to get .sra file",
            "doc": "A simple download tool to get .sra file from a repository of INSDC members. https://github.com/inutano/download-sra",
            "hints": [
                {
                    "dockerPull": "ghcr.io/inutano/download-sra:a827d85",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": [
                "download-sra"
            ],
            "inputs": [
                {
                    "type": "string",
                    "default": "ddbj",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-r"
                    },
                    "id": "#download-sra.cwl/repo"
                },
                {
                    "type": [
                        "string",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#download-sra.cwl/run_ids"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*sra"
                    },
                    "id": "#download-sra.cwl/sraFiles"
                }
            ],
            "id": "#download-sra.cwl",
            "https://schema.org/license": "https://spdx.org/licenses/Apache-2.0",
            "https://schema.org/codeRepository": "https://github.com/pitagora-network/pitagora-cwl",
            "https://schema.org/author": [
                {
                    "class": "https://schema.org/Person",
                    "https://schema.org/identifier": "https://orcid.org/0000-0003-3777-5945",
                    "https://schema.org/email": "mailto:inutano@gmail.com",
                    "https://schema.org/name": "Tazro Ohta"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "pfastq-dump: A bash implementation of parallel-fastq-dump, parallel fastq-dump wrapper",
            "doc": "pfastq-dump is a bash implementation of parallel-fastq-dump, parallel fastq-dump wrapper. --stdout option is additionally supported, but almost same features. It also uses -N and -X options of fastq-dump to specify blocks of data to be decompressed separately. https://github.com/inutano/pfastq-dump",
            "hints": [
                {
                    "dockerPull": "quay.io/inutano/sra-toolkit:v2.9.0",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": [
                "pfastq-dump"
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "inputBinding": {
                        "prefix": "--gzip"
                    },
                    "id": "#pfastq-dump.cwl/gzip"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "prefix": "-t"
                    },
                    "id": "#pfastq-dump.cwl/nthreads"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "inputBinding": {
                        "prefix": "--readids"
                    },
                    "id": "#pfastq-dump.cwl/readids"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "inputBinding": {
                        "prefix": "--skip-technical"
                    },
                    "id": "#pfastq-dump.cwl/skip_technical"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "inputBinding": {
                        "prefix": "--split-files"
                    },
                    "id": "#pfastq-dump.cwl/split_files"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "inputBinding": {
                        "prefix": "--split-spot"
                    },
                    "id": "#pfastq-dump.cwl/split_spot"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 50
                    },
                    "id": "#pfastq-dump.cwl/sraFiles"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "format": "http://edamontology.org/format_1930",
                    "outputBinding": {
                        "glob": "*fastq*"
                    },
                    "id": "#pfastq-dump.cwl/fastqFiles"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_1930",
                    "outputBinding": {
                        "glob": "*_1.fastq*"
                    },
                    "id": "#pfastq-dump.cwl/forward"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_1930",
                    "outputBinding": {
                        "glob": "*_2.fastq*"
                    },
                    "id": "#pfastq-dump.cwl/reverse"
                }
            ],
            "id": "#pfastq-dump.cwl",
            "https://schema.org/license": "https://spdx.org/licenses/Apache-2.0",
            "https://schema.org/codeRepository": "https://github.com/pitagora-network/pitagora-cwl",
            "https://schema.org/author": [
                {
                    "class": "https://schema.org/Person",
                    "https://schema.org/identifier": "https://orcid.org/0000-0003-3777-5945",
                    "https://schema.org/email": "mailto:inutano@gmail.com",
                    "https://schema.org/name": "Tazro Ohta"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "quay.io/biocontainers/samtools:1.9--h46bd0b3_0",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": [
                "samtools",
                "sort"
            ],
            "arguments": [
                {
                    "prefix": "-o",
                    "valueFrom": "$(runtime.outdir)/$(inputs.output_filename)"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 50
                    },
                    "id": "#samtools_sort.cwl/input_bam"
                },
                {
                    "type": "int",
                    "default": 1,
                    "inputBinding": {
                        "prefix": "-@"
                    },
                    "id": "#samtools_sort.cwl/nthreads"
                },
                {
                    "type": "string",
                    "default": "sorted.bam",
                    "id": "#samtools_sort.cwl/output_filename"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_filename)"
                    },
                    "id": "#samtools_sort.cwl/sorted_bamfile"
                }
            ],
            "id": "#samtools_sort.cwl",
            "https://schema.org/license": "https://spdx.org/licenses/Apache-2.0",
            "https://schema.org/codeRepository": "https://github.com/pitagora-network/pitagora-cwl",
            "https://schema.org/author": [
                {
                    "class": "https://schema.org/Person",
                    "https://schema.org/identifier": "https://orcid.org/0000-0003-3777-5945",
                    "https://schema.org/email": "mailto:inutano@gmail.com",
                    "https://schema.org/name": "Tazro Ohta"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "STAR mapping: running mapping jobs.",
            "doc": "STAR: Spliced Transcripts Alignment to a Reference. https://github.com/alexdobin/STAR/blob/master/doc/STARmanual.pdf",
            "hints": [
                {
                    "dockerPull": "quay.io/biocontainers/star:2.6.0c--0",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": [
                "STAR"
            ],
            "arguments": [
                {
                    "prefix": "--outFileNamePrefix",
                    "valueFrom": "$(runtime.outdir)/$(inputs.output_dir_name)"
                }
            ],
            "inputs": [
                {
                    "label": "maximum intron size",
                    "doc": "maximum intron size, if 0, max intron size will be determined by (2\u02c6winBinNbits)*winAnchorDistNbins",
                    "type": "int",
                    "default": 1000000,
                    "inputBinding": {
                        "prefix": "--alignIntronMax"
                    },
                    "id": "#star_mapping_pe.cwl/alignIntronMax"
                },
                {
                    "label": "minimum intron size",
                    "doc": "minimum intron size: genomic gap is considered intron if its length>=alignIntronMin, otherwise it is considered Deletion",
                    "type": "int",
                    "default": 20,
                    "inputBinding": {
                        "prefix": "--alignIntronMin"
                    },
                    "id": "#star_mapping_pe.cwl/alignIntronMin"
                },
                {
                    "label": "maximum gap between two mates",
                    "doc": "maximum gap between two mates, if 0, max intron gap will be determined by (2\u02c6winBinNbits)*winAnchorDistNbins",
                    "type": "int",
                    "default": 1000000,
                    "inputBinding": {
                        "prefix": "--alignMatesGapMax"
                    },
                    "id": "#star_mapping_pe.cwl/alignMatesGapMax"
                },
                {
                    "label": "minimum overhang (i.e. block size) for annotated (sjdb) spliced alignments",
                    "doc": "minimum overhang (i.e. block size) for annotated (sjdb) spliced alignments",
                    "type": "int",
                    "default": 1,
                    "inputBinding": {
                        "prefix": "--alignSJDBoverhangMin"
                    },
                    "id": "#star_mapping_pe.cwl/alignSJDBoverhangMin"
                },
                {
                    "label": "minimum overhang (i.e. block size) for spliced alignments",
                    "doc": "minimum overhang (i.e. block size) for spliced alignments",
                    "type": "int",
                    "default": 8,
                    "inputBinding": {
                        "prefix": "--alignSJoverhangMin"
                    },
                    "id": "#star_mapping_pe.cwl/alignSJoverhangMin"
                },
                {
                    "label": "path to file that contain input read1",
                    "doc": "path to file that contain input read1",
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--readFilesIn",
                        "position": 50
                    },
                    "id": "#star_mapping_pe.cwl/fq1"
                },
                {
                    "label": "path to file that contain input read2",
                    "doc": "path to file that contain input read2",
                    "type": "File",
                    "inputBinding": {
                        "position": 51
                    },
                    "id": "#star_mapping_pe.cwl/fq2"
                },
                {
                    "label": "path to the directory where genome files are stored",
                    "doc": "path to the directory where genome files are stored",
                    "type": "Directory",
                    "inputBinding": {
                        "prefix": "--genomeDir"
                    },
                    "id": "#star_mapping_pe.cwl/genomeDir"
                },
                {
                    "label": "maximum available RAM for sorting BAM",
                    "doc": "maximum available RAM for sorting BAM. If =0, it will be set to the genome index size. 0 value can only be used with \u2013genomeLoad NoSharedMemory option",
                    "type": [
                        "null",
                        "long"
                    ],
                    "inputBinding": {
                        "prefix": "--limitBAMsortRAM"
                    },
                    "id": "#star_mapping_pe.cwl/limitBAMsortRAM"
                },
                {
                    "label": "Number of threads",
                    "doc": "defines the number of threads to be used for genome generation, it has to be set to the number of available cores on the server node.",
                    "type": "int",
                    "inputBinding": {
                        "prefix": "--runThreadN"
                    },
                    "id": "#star_mapping_pe.cwl/nthreads"
                },
                {
                    "label": "BAM compression level",
                    "doc": "BAM compression level, -1=default compression (6?), 0=no compression, 10=maximum compression",
                    "type": "int",
                    "default": 10,
                    "inputBinding": {
                        "prefix": "--outBAMcompression"
                    },
                    "id": "#star_mapping_pe.cwl/outBAMcompression"
                },
                {
                    "label": "alignment will be output only if it has no more mismatches than this value",
                    "doc": "alignment will be output only if it has no more mismatches than this value",
                    "type": "int",
                    "default": 999,
                    "inputBinding": {
                        "prefix": "--outFilterMismatchNmax"
                    },
                    "id": "#star_mapping_pe.cwl/outFilterMismatchNmax"
                },
                {
                    "label": "alignment will be output only if its ratio of mismatches to *read* length is less than or equal to this value.",
                    "doc": "alignment will be output only if its ratio of mismatches to *read* length is less than or equal to this value.",
                    "type": "float",
                    "default": 0.04,
                    "inputBinding": {
                        "prefix": "--outFilterMismatchNoverReadLmax"
                    },
                    "id": "#star_mapping_pe.cwl/outFilterMismatchNoverReadLmax"
                },
                {
                    "label": "maximum number of loci the read is allowed to map to",
                    "doc": "maximum number of loci the read is allowed to map to. Alignments (all of them) will be output only if the read maps to no more loci than this value. Otherwise no alignments will be output, and the read will be counted as \u201dmapped to too many loci\u201d in the Log.final.out .",
                    "type": "int",
                    "default": 20,
                    "inputBinding": {
                        "prefix": "--outFilterMultimapNmax"
                    },
                    "id": "#star_mapping_pe.cwl/outFilterMultimapNmax"
                },
                {
                    "label": "type of filtering",
                    "doc": "Normal: standard filtering using only current alignment, BySJout: keep only those reads that contain junctions that passed filtering into SJ.out.tab",
                    "type": "string",
                    "default": "BySJout",
                    "inputBinding": {
                        "prefix": "--outFilterType"
                    },
                    "id": "#star_mapping_pe.cwl/outFilterType"
                },
                {
                    "label": "a string of desired SAM attributes, in the order desired for the output SAM",
                    "doc": "NH: any combination in any order, Standard: NH HI AS nM, All: NH HI AS nM NM MD jM jI ch, None: no attributes",
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "default": [
                        "NH",
                        "HI",
                        "AS",
                        "NM",
                        "MD"
                    ],
                    "inputBinding": {
                        "prefix": "--outSAMattributes"
                    },
                    "id": "#star_mapping_pe.cwl/outSAMattributes"
                },
                {
                    "label": "Cuffinks-like strand field flag",
                    "doc": "Cuffinks-like strand field flag. None: not used, intronMotif: strand derived from the intron motif. Reads with inconsistent and/or non-canonical introns are filtered out.",
                    "type": "string",
                    "default": "intronMotif",
                    "inputBinding": {
                        "prefix": "--outSAMstrandField"
                    },
                    "id": "#star_mapping_pe.cwl/outSAMstrandField"
                },
                {
                    "label": "type of SAM/BAM output",
                    "doc": "1st word: BAM: output BAM without sorting, SAM: output SAM without sorting, None: no SAM/BAM output, 2nd, 3rd: Unsorted: standard unsorted, SortedByCoordinate: sorted by coordinate. This option will allocate extra memory for sorting which can be specified by \u2013limitBAMsortRAM",
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "default": [
                        "BAM",
                        "Unsorted"
                    ],
                    "inputBinding": {
                        "prefix": "--outSAMtype"
                    },
                    "id": "#star_mapping_pe.cwl/outSAMtype"
                },
                {
                    "label": "output of unmapped reads in the SAM format",
                    "doc": "1st word: None: no output, Within: output unmapped reads within the main SAM file (i.e. Aligned.out.sam). 2nd word: KeepPairs: record unmapped mate for each alignment, and, in case of unsorted output, keep it adjacent to its mapped mate. Only a\u21b5ects multi-mapping reads.",
                    "type": "string",
                    "default": "Within",
                    "inputBinding": {
                        "prefix": "--outSAMunmapped"
                    },
                    "id": "#star_mapping_pe.cwl/outSAMunmapped"
                },
                {
                    "label": "which reads to consider for collapsed splice junctions output",
                    "doc": "which reads to consider for collapsed splice junctions output. All: all reads, unique- and multi-mappers, Unique: uniquely mapping reads only.",
                    "type": "string",
                    "default": "Unique",
                    "inputBinding": {
                        "prefix": "--outSJfilterReads"
                    },
                    "id": "#star_mapping_pe.cwl/outSJfilterReads"
                },
                {
                    "label": "Name of the directory to write output files in",
                    "doc": "Name of the directory to write output files in",
                    "type": "string",
                    "default": "STAR",
                    "id": "#star_mapping_pe.cwl/output_dir_name"
                },
                {
                    "label": "types of quantification requested",
                    "doc": "types of quantification requested. -: none, TranscriptomeSAM: output SAM/BAM alignments to transcriptome into a separate file, GeneCounts: count reads per gene",
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "default": [
                        "TranscriptomeSAM",
                        "GeneCounts"
                    ],
                    "inputBinding": {
                        "prefix": "--quantMode"
                    },
                    "id": "#star_mapping_pe.cwl/quantMode"
                },
                {
                    "label": "transcriptome BAM compression level",
                    "doc": "transcriptome BAM compression level, -1=default compression (6?), 0=no compression, 10=maximum compression",
                    "type": "int",
                    "default": 10,
                    "inputBinding": {
                        "prefix": "--quantTranscriptomeBAMcompression"
                    },
                    "id": "#star_mapping_pe.cwl/quantTranscriptomeBAMcompression"
                },
                {
                    "label": "extra alignment score for alignmets that cross database junctions",
                    "doc": "extra alignment score for alignmets that cross database junctions",
                    "type": "int",
                    "default": 1,
                    "inputBinding": {
                        "prefix": "--sjdbScore"
                    },
                    "id": "#star_mapping_pe.cwl/sjdbScore"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*.out"
                    },
                    "id": "#star_mapping_pe.cwl/logfiles"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*Aligned.out.bam"
                    },
                    "id": "#star_mapping_pe.cwl/output_bam"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*ReadsPerGene.out.tab"
                    },
                    "id": "#star_mapping_pe.cwl/readsPerGene"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*SJ.out.tab"
                    },
                    "id": "#star_mapping_pe.cwl/spliceJunctions"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*Aligned.toTranscriptome.out.bam"
                    },
                    "id": "#star_mapping_pe.cwl/toTranscriptome_bam"
                }
            ],
            "id": "#star_mapping_pe.cwl",
            "https://schema.org/license": "https://spdx.org/licenses/Apache-2.0",
            "https://schema.org/codeRepository": "https://github.com/pitagora-network/pitagora-cwl",
            "https://schema.org/author": [
                {
                    "class": "https://schema.org/Person",
                    "https://schema.org/identifier": "https://orcid.org/0000-0003-3777-5945",
                    "https://schema.org/email": "mailto:inutano@gmail.com",
                    "https://schema.org/name": "Tazro Ohta"
                }
            ]
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "https://schema.org/version/latest/schemaorg-current-http.rdf",
        "http://edamontology.org/EDAM_1.18.owl"
    ],
    "$namespaces": {
        "s": "https://schema.org/",
        "edam": "http://edamontology.org/"
    }
}
